@@ -68,8 +68,8 @@ def _ngcbash(
                 "FZF error: {}".format(error)
             )
 
-    logger.warning(f"bash exec {select_run}")
-    job_id = select_run[:7]
+    logger.warning(f"bash exec {select_run[0]}")
+    job_id = select_run[0][:7]
     os.system(f'ngc batch exec {job_id}')
 
 def _ngckill(
